==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/outputs/P2SVpnServerConfigVpnClientRevokedCertificateResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * VPN client revoked certificate of P2SVpnServerConfiguration.
 * @property etag A unique read-only string that changes whenever the resource is updated.
 * @property id Resource ID.
 * @property name The name of the resource that is unique within a resource group. This name can be used to access the resource.
 * @property provisioningState The provisioning state of the VPN client revoked certificate resource.
 * @property thumbprint The revoked VPN client certificate thumbprint.
 */
public data class P2SVpnServerConfigVpnClientRevokedCertificateResponse(
    public val etag: String? = null,
    public val id: String? = null,
    public val name: String? = null,
    public val provisioningState: String,
    public val thumbprint: String? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.network.outputs.P2SVpnServerConfigVpnClientRevokedCertificateResponse):
            P2SVpnServerConfigVpnClientRevokedCertificateResponse =
            P2SVpnServerConfigVpnClientRevokedCertificateResponse(
                etag = javaType.etag().map({ args0 -> args0 }).orElse(null),
                id = javaType.id().map({ args0 -> args0 }).orElse(null),
                name = javaType.name().map({ args0 -> args0 }).orElse(null),
                provisioningState = javaType.provisioningState(),
                thumbprint = javaType.thumbprint().map({ args0 -> args0 }).orElse(null),
            )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/network/kotlin/outputs/P2SVpnServerConfigVpnClientRevokedCertificateResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * VPN client revoked certificate of P2SVpnServerConfiguration.
 * @property etag A unique read-only string that changes whenever the resource is updated.
 * @property id Resource ID.
 * @property name The name of the resource that is unique within a resource group. This name can be used to access the resource.
 * @property provisioningState The provisioning state of the VPN client revoked certificate resource.
 * @property thumbprint The revoked VPN client certificate thumbprint.
 */
public data class P2SVpnServerConfigVpnClientRevokedCertificateResponse(
    public val etag: String? = null,
    public val id: String? = null,
    public val name: String? = null,
    public val provisioningState: String,
    public val thumbprint: String? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.network.outputs.P2SVpnServerConfigVpnClientRevokedCertificateResponse): P2SVpnServerConfigVpnClientRevokedCertificateResponse =
            P2SVpnServerConfigVpnClientRevokedCertificateResponse(
                etag = javaType.etag().map({ args0 -> args0 }).orElse(null),
                id = javaType.id().map({ args0 -> args0 }).orElse(null),
                name = javaType.name().map({ args0 -> args0 }).orElse(null),
                provisioningState = javaType.provisioningState(),
                thumbprint = javaType.thumbprint().map({ args0 -> args0 }).orElse(null),
            )
    }
}
